@@ -8,9 +8,7 @@ use warnings;
 use Carp;
 use Storable ();
 
-our $VERSION = '0.012_02';
-
-use constant HASH_REF	=> ref {};
+our $VERSION = '0.001';
 
 BEGIN {
     local $@ = undef;
@@ -51,21 +49,6 @@ sub _default_agent {
     return join '/', "Mock $agent", $self->VERSION();
 }
 
-# NOTE this is only the static functionality.
-sub can_ssl {
-    local $@ = undef;
-    my ( $ok, $reason ) = ( 1, '' );
-    eval {
-	require IO::Socket::SSL;
-	IO::Socket::SSL->VERSION( 1.42 );
-	1;
-    } or ( $ok, $reason ) = 
-    ( 0, "IO::Socket::SSL 1.42 must be installed for https support\n" );
-    wantarray
-	or return $ok;
-    return ( $ok, $reason );
-}
-
 sub head {
     my ( $self, $url ) = @_;
     return $self->request( HEAD => $url );
@@ -74,20 +57,15 @@ sub head {
 sub request {
     my ( $self, undef, $url ) = @_;
     $self->{status} ||= Storable::retrieve( $self->{fn} );
-    my $resp = $self->{status}{$url};
-    HASH_REF eq ref $resp
-	or $resp = {
-	status	=> $resp || 404,
+    my $status = $self->{status}{$url} || 404;
+    return {
+	success	=> _is_success( $status ),
+	url	=> $url,
+	status	=> $status,
+	reason	=> _status_message( $status ),
+	content	=> '',
+	headers	=> {},
     };
-    $resp->{success} = _is_success( $resp->{status} );
-    defined $resp->{reason}
-	or $resp->{reason} = _status_message( $resp->{status} );
-    defined $resp->{url}
-	or $resp->{url} = $url;
-    defined $resp->{content}
-	or $resp->{content} = '';
-    $resp->{headers} ||= {};
-    return $resp;
 }
 
 sub _is_success {
@@ -156,19 +134,6 @@ the real L<HTTP::Tiny|HTTP::Tiny>.
 
 This method retrieves (but does not set) the user agent string.
 
-=head2 can_ssl
-
- my $ok = HTTP::Tiny->can_ssl();
- my ( $ok, $reason ) = HTTP::Tiny->can_ssl();
-
-If called in scalar context, this static method returns a true value if
-L<IO::Socket::SSL|IO::Socket::SSL> is available and a false value
-otherwise. In list context, if C<$ok> is false C<$resource> will contain
-the reason why not.
-
-The L<HTTP::Tiny> functionality when the invocant is an object is not
-provided.
-
 =head2 head
 
  my $resp = $ua->head( $url );
@@ -218,9 +183,7 @@ L<HTTP::Tiny|HTTP::Tiny> (the real one).
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Test-Pod-LinkCheck-Lite>,
-L<https://github.com/trwyant/perl-Test-Pod-LinkCheck-Lite/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -228,7 +191,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2019-2024 by Thomas R. Wyant, III
+Copyright (C) 2019 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
