@@ -8,7 +8,7 @@ use warnings;			# Core since 5.6.0
 use utf8;			# Core since 5.6.0
 
 use B::Keywords ();		# Not core
-use Exporter ();		# Core since 5.0
+use Carp ();			# Core since 5.0
 use File::Find ();		# Core since 5.0
 use File::Spec;			# Core since 5.4.5
 use HTTP::Tiny;			# Core since 5.13.9
@@ -17,21 +17,11 @@ use Module::Load::Conditional ();	# Core since 5.9.5
 use Pod::Perldoc ();		# Core since 5.8.1
 use Pod::Simple ();		# Core since 5.9.3
 use Pod::Simple::LinkSection;	# Core since 5.9.3 (part of Pod::Simple)
+use Scalar::Util ();		# Core since 5.7.3
 use Storable ();		# Core since 5.7.3
 use Test::Builder ();		# Core since 5.6.2
 
-our $VERSION = '0.012_02';
-
-our @ISA = qw{ Exporter };
-
-our @EXPORT_OK = qw{
-    ALLOW_REDIRECT_TO_INDEX
-    MAYBE_IGNORE_GITHUB
-};
-
-our %EXPORT_TAGS = (
-    const	=> [ grep { m/ \A [[:upper:]_]+ \z /smx } @EXPORT_OK ],
-);
+our $VERSION = '0.001';
 
 use constant ON_DARWIN		=> 'darwin' eq $^O;
 use constant ON_VMS		=> 'VMS' eq $^O;
@@ -55,38 +45,6 @@ use constant SCALAR_REF	=> ref \0;
 # fix-up is not needed, the optimizer ditches it.
 use constant NEED_MAN_FIX	=> Pod::Simple->VERSION lt '3.24';
 
-use constant ALLOW_REDIRECT_TO_INDEX => sub {
-    my ( undef, $resp, $url ) = @_;
-    # Does not apply to non-hierarchical URLs. This list is derived from
-    # the URI distribution, and represents those classes that do not
-    # inherit from URI::_generic.
-    $url =~ m/ \A (?: data | mailto | urn ) : /smxi
-	and return $resp->{url} ne $url;
-    $url =~ m| / \z |smx
-	or return $resp->{url} ne $url;
-    ( my $resp_url = $resp->{url} ) =~ s| (?<= / ) [^/]* \z ||smx;
-    return $resp_url ne $url;
-};
-
-use constant MAYBE_IGNORE_GITHUB	=> sub {
-    m< \A https://github\.com \b >smx
-	or return;
-    my $git_dir = $ENV{GIT_DIR} || '.git';
-    -d $git_dir
-	or return 1;
-    open my $fh, '-|', qw{ git remote --verbose }	## no critic (RequireBriefOpen)
-	or return 1;
-    local $_ = undef;	# while (<>) ... does not localize $_.
-    while ( <$fh> ) {
-	m< \b https://github\.com \b >smx
-	    and return;
-    }
-    return 1;
-};
-
-use constant USER_AGENT_CLASS	=> 'HTTP::Tiny';
-
-
 # NOTE that Test::Builder->new() gets us a singleton. For this reason I
 # use $Test::Builder::Level (localized) to get tests reported relative
 # to the correct file and line, rather than setting the 'level'
@@ -126,6 +84,10 @@ sub new {
     }
 }
 
+sub _default_agent {
+    return HTTP::Tiny->new()->agent();
+}
+
 sub _default_allow_man_spaces {
     return 0;
 }
@@ -134,10 +96,6 @@ sub _default_check_external_sections {
     return 1;
 }
 
-sub _default_cache_url_response {
-    return 1;
-}
-
 sub _default_check_url {
     return 1;
 }
@@ -177,12 +135,6 @@ sub _default_ignore_url {
     }
 }
 
-sub _default_add_dir {
-    -d 'blib/script'
-	and return [ 'blib/script' ];
-    return [];
-}
-
 sub _default_module_index {
     my @handlers;
     foreach ( keys %Test::Pod::LinkCheck::Lite:: ) {
@@ -195,25 +147,13 @@ sub _default_module_index {
     return \@handlers;
 }
 
-sub _default_prohibit_redirect {
-    return 0;
-}
-
 sub _default_require_installed {
     return 0;
 }
 
-sub _default_skip_server_errors {
-    return 1;
-}
-
-sub _default_user_agent {
-    return USER_AGENT_CLASS;
-}
-
-sub _init_add_dir {
+sub _init_agent {
     my ( $self, $name, $value ) = @_;
-    $self->{$name} = [ grep { -d } ref $value ? @{ $value } : $value ];
+    $self->{$name} = $value;
     return;
 }
 
@@ -223,12 +163,6 @@ sub _init_allow_man_spaces {
     return;
 }
 
-sub _init_cache_url_response {
-    my ( $self, $name, $value ) = @_;
-    $self->{$name} = $value ? 1 : 0;
-    return;
-}
-
 sub _init_check_external_sections {
     my ( $self, $name, $value ) = @_;
     $self->{$name} = $value ? 1 : 0;
@@ -314,59 +248,14 @@ sub _init_module_index {
     return;
 }
 
-sub _init_prohibit_redirect {
-    my ( $self, $name, $value ) = @_;
-    if ( CODE_REF eq ref $value ) {
-	$self->{$name} = $self->{"_$name"} = $value;
-    } elsif ( $value ) {
-	$self->{$name} = 1;
-	$self->{"_$name"} = sub {
-	    my ( undef, $resp, $url ) = @_;
-	    return $resp->{url} ne $url;
-	};
-    } else {
-	$self->{$name} = 0;
-	$self->{"_$name"} = sub {
-	    return 0;
-	};
-    }
-    return;
-}
-
 sub _init_require_installed {
     my ( $self, $name, $value ) = @_;
     $self->{$name} = $value ? 1 : 0;
     return;
 }
 
-sub _init_skip_server_errors {
-    my ( $self, $name, $value ) = @_;
-    $self->{$name} = $value ? 1 : 0;
-    return;
-}
-
-sub _init_user_agent {
-    my ( $self, $name, $value ) = @_;
-    defined $value
-	or $value = USER_AGENT_CLASS;
-    eval {
-	$value->isa( USER_AGENT_CLASS )
-    } or Carp::confess(
-	"Invalid user_agent value '$value': must be a subclass of HTTP::Tiny, or undef" );
-    $self->{$name} = $value;
-    if ( ref $value ) {
-	$self->{_user_agent} = $value;
-    } else {
-	# Probably unnecessary, but I'm paranoid.
-	delete $self->{_user_agent};
-    }
-    return;
-}
-
 sub agent {
     my ( $self ) = @_;
-    defined $self->{agent}
-	or $self->{agent} = $self->_user_agent()->agent();
     return $self->{agent};
 }
 
@@ -409,16 +298,6 @@ sub allow_man_spaces {
     return $self->{allow_man_spaces}
 }
 
-sub cache_url_response {
-    my ( $self ) = @_;
-    return $self->{cache_url_response}
-}
-
-sub can_ssl {
-    my ( $self ) = @_;
-    return $self->{user_agent}->can_ssl();
-}
-
 sub check_external_sections {
     my ( $self ) = @_;
     return $self->{check_external_sections}
@@ -443,8 +322,6 @@ sub configuration {
 ${leader}'agent' is '@{[ $self->agent() ]}'
 ${leader}'allow_man_spaces' is @{[ _Boolean(
     $self->allow_man_spaces() ) ]}
-${leader}'cache_url_response' is @{[ _Boolean(
-    $self->cache_url_response() ) ]}
 ${leader}'check_external_sections' is @{[ _Boolean(
     $self->check_external_sections() ) ]}
 ${leader}'check_url' is @{[ _Boolean( $self->check_url() ) ]}
@@ -452,9 +329,7 @@ ${leader}'ignore_url' is $ignore_url
 ${leader}'man' is @{[ _Boolean( $self->man() ) ]}
 ${leader}'module_index' is ( @{[ join ', ', map { "'$_'" }
     $self->module_index() ]} )
-${leader}'prohibit_redirect' is @{[ _Boolean( $self->prohibit_redirect() ) ]}
 ${leader}'require_installed' is @{[ _Boolean( $self->require_installed() ) ]}
-${leader}'skip_server_errors' is @{[ _Boolean( $self->skip_server_errors() ) ]}
 EOD
 }
 
@@ -558,37 +433,16 @@ sub pod_file_ok {
 	$self->{_test}{fail};
 }
 
-sub prohibit_redirect {
-    my ( $self ) = @_;
-    return $self->{prohibit_redirect};
-}
-
 sub require_installed {
     my ( $self ) = @_;
     return $self->{require_installed};
 }
 
-sub skip_server_errors {
-    my ( $self ) = @_;
-    return $self->{skip_server_errors};
-}
-
-# This is a private method, but because it had to be accessed (read:
-# monkey-patched) to get badly-needed user functionality, it needs to
-# fulfill its interface contract until March 1 2024 or one year after
-# the release of version 0.011, whichever is later. That contract is:
-# * Name: _user_agent
-# * Arguments: none
-# * Return: HTTP::Tiny object, which may be a subclass.
 sub _user_agent {
     my ( $self ) = @_;
-    return( $self->{_user_agent} ||= do {
-	    my @arg;
-	    defined $self->{agent}
-		and push @arg, agent => $self->{agent};
-	    $self->{user_agent}->new( @arg );
-	}
-    );
+    return( $self->{_user_agent} ||= HTTP::Tiny->new(
+	    agent	=> $self->agent(),
+	) );
 }
 
 sub _pass {
@@ -612,6 +466,7 @@ sub _fail {
 sub _skip {
     my ( $self, @msg ) = @_;
     local $Test::Builder::Level =  _nest_depth();
+    $DB::single = 1;
     $TEST->skip( $self->__build_test_msg( @msg ) );
     $self->{_test}{skip}++;
     return 0;
@@ -647,37 +502,20 @@ sub __build_test_msg {
 # for module documentation (whether in the .pm or a separate .pod), or
 # regular .pod documentation (e.g. perldelta.pod).
 sub _get_installed_doc_info {
-    my ( $self, $module ) = @_;
-
-    # NOTE we have to do this by hand, because Pod::Perldoc searches
-    # Perl's bin/ BEFORE the contents of @INC.
-    ( my $file = $module ) =~ s(::)('/)g;
-    foreach my $dir ( @{ $self->{add_dir} } ) {
-	foreach my $ext ( '', qw{ .pod .pm } ) {
-	    my $path = "$dir/$file$ext";
-	    -e $path
-		and -s _
-		and -T _
-		and return {
-		file	=> $path,
-	    };
-	}
-    }
-
+    my ( undef, $module ) = @_;
     my $pd = Pod::Perldoc->new();
 
     # Pod::Perldoc writes to STDERR if the module (or whatever) is not
     # installed, so we localize STDERR and reopen it to the null device.
     # The reopen of STDERR is unchecked because if it fails we still
     # want to run the tests. They just may be noisy.
-    my $path;
-    {
-	local *STDERR;
-	open STDERR, '>', File::Spec->devnull();	## no critic (RequireCheckedOpen)
+    local *STDERR;
+    open STDERR, '>', File::Spec->devnull();	## no critic (RequireCheckedOpen)
 
-	# NOTE that grand_search_init() is undocumented.
-	( $path ) = $pd->grand_search_init( [ $module ] );
-    }
+    # NOTE that grand_search_init() is undocumented.
+    my ( $path ) = $pd->grand_search_init( [ $module ] );
+
+    close STDERR;
 
     defined $path
 	and return {
@@ -688,7 +526,6 @@ sub _get_installed_doc_info {
     # called) for why this check is done.
     Module::Load::Conditional::check_install( module	=> $module )
 	and return {
-	file		=> $path,
 	undocumented	=> 1,
     };
 
@@ -792,7 +629,7 @@ sub _check_external_pod_info {
 	# the existence of the module, and _assuming_ that it was
 	# documented.
 	$data->{undocumented}
-	    and return $self->_fail( $link,
+	    and $self->_fail(
 	    "$module is installed but undocumented" );
 
 	# If we get this far it is an installed module with
@@ -871,7 +708,6 @@ sub _get_module_index_cpan {
 
     # The following code reproduces
     # CPAN::HandleConfig::cpan_home_dir_candidates()
-    # as of CPAN::HandleConfig version 5.5011.
     my @dir_list;
 
     if ( _has_usable( 'File::HomeDir', 0.52 ) ) {
@@ -937,6 +773,7 @@ sub _get_module_index_cpan_meta_db {
 sub _handle_url {
     my ( $self, $link ) = @_;
 
+
     $self->check_url()
 	or return $self->_skip( $link, 'not checked; url checks disabled' );
 
@@ -945,49 +782,15 @@ sub _handle_url {
     my $url = "$link->[1]{to}"	# Stringify object
 	or return $self->_fail( $link, 'contains no url' );
 
-    if ( $url =~ m/ \A https : /smxi ) {
-	my ( $ok, $why ) = $self->can_ssl();
-	unless ( $ok ) {
-	    $self->{_ssl_warning}
-		or $TEST->diag( "Can not check https: links: $why" );
-	    $self->{_ssl_warning} = 1;
-	    return $self->_skip(
-		$link, 'not checked: https: checks unavailable' );
-	}
-    }
-
     $self->__ignore_url( $url )
 	and return $self->_skip( $link, 'not checked; explicitly ignored' );
 
-    my $resp;
-    if ( $self->cache_url_response() ) {
-	$resp = $self->{_cache_url_response}{$url} ||=
-	    $user_agent->head( $url );
-    } else {
-	$resp = $user_agent->head( $url );
-    }
+    my $resp = $user_agent->head( $url );
 
-    if ( $resp->{success} ) {
+    $resp->{success}
+	and return 0;
 
-	my $code = $self->{_prohibit_redirect};
-	while ( $code = $code->( $self, $resp, $url ) ) {
-	    CODE_REF eq ref $code
-		or return $self->_fail( $link, "redirected to $resp->{url}" );
-	}
-
-	return 0;
-
-    } else {
-
-	$self->skip_server_errors()
-	    and $resp->{status} =~ m/ \A 5 /smx
-	    and return $self->_skip( $link,
-		"not checked: server error $resp->{status} $resp->{reason}" );
-
-	return $self->_fail( $link,
-	    "broken: $resp->{status} $resp->{reason}" );
-
-    }
+    return $self->_fail( $link, "broken: $resp->{status} $resp->{reason}" );
 }
 
 {
@@ -1060,9 +863,9 @@ sub _is_perl_file {
     }
 }
 
-package My_Parser;		## no critic (ProhibitMultiplePackages)
+package		## no critic (ProhibitMultiplePackages)
+My_Parser;	# Cargo cult to hide package from toolchain.
 
-use Carp ();
 use Pod::Simple::PullParser;	# Core since 5.9.3 (part of Pod::Simple)
 
 @My_Parser::ISA = qw{ Pod::Simple::PullParser };
@@ -1081,11 +884,7 @@ sub run {
 	defined $source
 	    and $self->set_source( $source );
     my $attr = $self->_attr();
-    $attr->{ignore_tag} = [];
-    $attr->{line} = 1;
-    $attr->{links} = [];
-    $attr->{source} = $source;
-    $attr->{sections} = {};
+    @{ $attr }{ qw{ line links sections } } = ( 1, [], {} );
     while ( my $token = $self->get_token() ) {
 	if ( my $code = $self->can( '__token_' . $token->type() ) ) {
 	    $code->( $self, $token );
@@ -1126,13 +925,9 @@ sub __token_start {
 	foreach my $name ( qw{ section to } ) {
 	    my $sect = $token->attr( $name )
 		or next;
-	    my $norm = _normalize_text( "$sect" );
-	    splice @{ $sect }, 2;
-	    push @{ $sect }, $norm;
+	    @{ $sect }[ 2 .. $#$sect ] = ( _normalize_text( "$sect" ) );
 	}
 	push @{ $attr->{links} }, [ @{ $token }[ 1 .. $#$token ] ];
-    } elsif ( 'X' eq $tag ) {
-	push @{ $attr->{ignore_tag} }, $tag;
     } elsif ( $section_tag{$tag} ) {
 	$attr->{text} = '';
     }
@@ -1142,7 +937,6 @@ sub __token_start {
 sub __token_text {
     my ( $self, $token ) = @_;
     my $attr = $self->_attr();
-    return if @{ $attr->{ignore_tag} };
     my $text = $token->text();
     $attr->{line} += $text =~ tr/\n//;
     $attr->{text} .= $text;
@@ -1155,8 +949,6 @@ sub __token_end {
     my $tag = $token->tag();
     if ( $section_tag{$tag} ) {
 	$attr->{sections}{ _normalize_text( delete $attr->{text} ) } = 1;
-    } elsif( @{ $attr->{ignore_tag} } && $tag eq $attr->{ignore_tag}[-1] ) {
-	pop @{ $attr->{ignore_tag} };
     }
     return;
 }
@@ -1258,15 +1050,6 @@ or whatever). They will only be checked if the C<check_url> attribute is
 true, and can only be successfully checked if Perl has access to the
 specified URL.
 
-B<NOTE> that C<https:> links can only be checked if
-L<IO::Socket::SSL|IO::Socket::SSL> version 1.42 (at least) and
-L<Net::SSLeay|Net::SSLeay> version 1.49 (at least) are installed. These
-are B<NOT> prerequisites of C<Test::Pod::LinkCheck::Lite> because they
-are not in core, and I am trying to keep non-core dependencies to a
-minimum. If these modules are not present an attempt to check an
-C<https:> link will result in a skipped test. In addition, a diagnostic
-will be issued for the first C<https:> link skipped by the test object.
-
 =item * pod (internal)
 
 These links are of the form C<< LE<lt>text|/sectionE<gt> >>. They are
@@ -1301,7 +1084,8 @@ for this information in the following places:
 
 =item File F<Metadata> in the directory used by the C<CPAN> client;
 
-=item Website L<https://cpanmetadb.plackperl.org/>, a.k.a. the CPAN Meta DB.
+=item Website L<https://cpanmetadb.plackperl.org/>, a.k.a. the CPAN Meta
+DB.
 
 =back
 
@@ -1317,7 +1101,8 @@ module has a section, a skipped test is generated.
 
 The C<::Lite> refers to the fact that a real effort has been made to
 reduce non-core dependencies. Under Perl 5.14 and up, the only known
-non-core dependency is L<B::Keywords|B::Keywords>.
+non-core dependencies are L<B::Keywords|B::Keywords> and
+L<Pod::Simple::SimpleTree|Pod::Simple::SimpleTree>.
 
 An effort has also been made to minimize the spawning of system
 commands.
@@ -1337,26 +1122,11 @@ The following arguments are supported:
 
 =over
 
-=item add_dir
-
-This argument is the name of a directory to search for extra POD, or a
-reference to an array of such directories. Directories that do not
-actually exist will be eliminated.
-
-The default is F<blib/script> if it exists, because otherwise links from
-modules to scripts will not be resolved.
-
 =item agent
 
 This argument is the user agent string to use for web access.
 
-B<Note> that this probably should have been called something more
-verbose like C<user_agent_string>, but I was influenced by the name
-used by L<HTTP::Tiny|HTTP::Tiny>, and did not anticipate the need for
-the interface to be able to specify the actual user agent.
-
-The default is C<undef>, which specifies whatever the actual user
-agent's C<agent()> method returns.
+The default is that of L<HTTP::Tiny|HTTP::Tiny>.
 
 =item allow_man_spaces
 
@@ -1367,17 +1137,6 @@ arguments on spaces.
 
 The default is false.
 
-=item cache_url_response
-
-This Boolean argument is set true to cache the responses from URL links.
-This means each URL is queried only once, no matter how many times it
-appears.
-
-This is an in-memory cache, and persists only for the life of the
-C<Test::Pod::LinkCheck::Lite> object.
-
-The default is true.
-
 =item check_external_sections
 
 This Boolean argument is true if the sections of links outside the
@@ -1479,30 +1238,6 @@ indices.
 
 By default all indices are considered.
 
-=item prohibit_redirect
-
-Added in version 0.004.
-
-This argument controls whether redirects are allowed in the resolution
-of a URL link.
-
-If a code reference is specified, it is called whenever a URL link is
-successfully resolved. The arguments are the
-C<Test::Pod::LinkCheck::Lite> object, the L<HTTP::Tiny> response hash,
-and the URL from the link. The code returns true to declare the link in
-error, false to allow it, or a code reference to defer the decision to
-that code. This latter is provided because I found the case where I
-wanted to do a little pre-processing and then defer to
-L<ALLOW_REDIRECT_TO_INDEX|/ALLOW_REDIRECT_TO_INDEX>, but could not find
-a clean way to use a manifest constant in a C<goto>.
-
-Any other value is interpreted as a Boolean. If the argument is true,
-any redirect is an error. If false, redirects are allowed.
-
-This argument is ignored unless L<check_url|/check_url> is true.
-
-The default is false, for historical reasons.
-
 =item require_installed
 
 This Boolean argument is true to disable the uninstalled module checks.
@@ -1511,35 +1246,6 @@ if the module exists.
 
 By default this is false.
 
-=item skip_server_errors
-
-Added in version 0.002.
-
-This Boolean argument is true to generate skips rather than failures if
-an attempt to check a URL link fails with a server error (status
-C<5xx>).
-
-By default this is true; it can be made false by passing value C<0> or
-C<''>.
-
-The default represents a change in the default behaviour from version
-C<0.001>, which failed a URL link if the check returned a server error.
-The logic (if any) in changing the default behaviour is that C<5xx>
-errors can represent actual server problems rather than errors in the
-link being checked, so changing the default behaviour eliminates
-possible false positives.
-
-=item user_agent
-
-Added in version 0.011
-
-This argument is either a class name or an object. Either way, it must
-be a subclass of L<HTTP::Tiny|HTTP::Tiny>.
-
-If a class name is passed, the class must already be loaded. An object
-of that class will be instantiated by calling its C<new()> method --
-with the agent argument if that was specified,
-
 =back
 
 =head2 agent
@@ -1573,21 +1279,6 @@ failures, passes, and skipped tests, in that order.
 
 This method returns the value of the C<'allow_man_spaces'> attribute.
 
-=head2 cache_url_response
-
- $t->cache_url_response()
-   and say 'URL responses are cached';
-
-This method returns the value of the C<'cache_url_response'> attribute.
-
-=head2 can_ssl
-
-Added in version 0.012.
-
-This convenience method wraps the user agent's method of the same name.
-See C<can_ssl()> in the user agent's documentation for what is returned.
-This will be L<HTTP::Tiny|HTTP::Tiny> by default.
-
 =head2 check_external_sections
 
  $t->check_external_sections()
@@ -1643,15 +1334,6 @@ If called in scalar context, this method returns the number of test
 failures encountered. If called in list context it return the number of
 failures, passes, and skipped tests, in that order.
 
-=head2 prohibit_redirect
-
- $t->prohibit_redirect()
-     and say 'All URL links must resolve without redirection';
-
-Added in version 0.004.
-
-This method returns the value of the C<'prohibit_redirect'> attribute.
-
 =head2 require_installed
 
  $t->require_installed()
@@ -1659,54 +1341,6 @@ This method returns the value of the C<'prohibit_redirect'> attribute.
 
 This method returns the value of the C<'require_installed'> attribute.
 
-=head2 skip_server_errors
-
- $t->skip_server_errors()
-    and say 'URL links that return status 5xx are skipped';
-
-Added in version 0.002.
-
-This method returns the value of the C<'skip_server_errors'> attribute.
-
-=head1 MANIFEST CONSTANTS
-
-The following manifest constants can be imported by name, or using the
-C<:const> tag:
-
-=head2 ALLOW_REDIRECT_TO_INDEX
-
-Added in version 0.003.
-
-This manifest constant is intended to be used as a value of the
-C<'prohibit_redirect'> attribute. It is a reference to a piece of code
-that accepts old-style redirects of an hierarchical URL ending in a
-C<'/'> to an index of that leaf of the hierarchy.
-
-Because this is a minimal-dependency module, the code referred to by
-this constant works by hand-checking for an hierarchical scheme
-(anything but C<'data:'>, C<'mailto:'>, or C<'urn:'>). If a URL with an
-hierarchical scheme ends in C<'/'>, the URL in the response has
-everything after the last C<'/'> removed before comparison to the
-original URL.
-
-This mess exists because of my bias that old-style redirection to an
-index is a different beast than indirection in general, and ought to be
-allowed. If you disagree you can ignore this functionality, or
-re-implement to suit yourself.
-
-=head2 MAYBE_IGNORE_GITHUB
-
-Added in version 0.009.
-
-This manifest constant is intended to be used as a value of the
-C<'ignore_url'> attribute. It is a reference to a piece of code that
-ignores GitHub urls unless the directory specified by environment
-variable C<GIT_DIR> (default: F<.git/> exists, and GitHub is a remote
-for the repository.
-
-This is (maybe) a convenience for developers whose boilerplate includes
-GitHub links but have not yet uploaded to GitHub.
-
 =head1 SEE ALSO
 
 L<Test::Pod::LinkCheck|Test::Pod::LinkCheck> by Apocalypse (C<APOCAL>)
@@ -1733,15 +1367,13 @@ configurations, gave me an opportunity to make this module much more
 robust than it would otherwise have been. It is probably unfair to
 single out individual testers, but as the luck of the testing cycle
 would have it, results from Andreas J. König (C<ANDK>), Slaven Rezić
-(C<SREZIC>), Chris Williams (C<BINGOS>), and Alceu Rodrigues de Freitas
-Junior were particularly useful to me.
+(C<SREZIC>), and Chris Williams (C<BINGOS>) were particularly useful to
+me.
 
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Test-Pod-LinkCheck-Lite>,
-L<https://github.com/trwyant/perl-Test-Pod-LinkCheck-Lite/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -1749,7 +1381,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2019-2024 by Thomas R. Wyant, III
+Copyright (C) 2019 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
